from fastapi import FastAPI, Body, Request, Depends, HTTPException
from fastapi.middleware.cors import CORSMiddleware
from fastapi.responses import FileResponse
from pydantic import BaseModel
import openai
import os

app = FastAPI()

app.add_middleware(
    CORSMiddleware,
    allow_origins=["*"],
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)

class ChatRequest(BaseModel):
    message: str

def call_openai_api(message: str):
    # define your OpenAI API key here in user environment variables or in the code
    # openai.api_key = "your-openai-api-key"

    response = openai.ChatCompletion.create(
        model="gpt-3.5-turbo",
        messages=[
            {"role": "system", "content": "You are a helpful assistant."},
            {"role": "user", "content": message},
        ],
    )
    return response.choices[0].message.content

# following code is for serving the index.html file
@app.get("/")
async def get_root():
    file_path = os.path.join(os.path.dirname(__file__), "index.html")
    if not os.path.exists(file_path):
        raise HTTPException(status_code=404, detail="File not found")
    return FileResponse(file_path)

# following code makes the chat endpoint available
@app.post("/chat")
async def chat_endpoint(chat_request: ChatRequest):
    response = call_openai_api(chat_request.message)
    return {"response": response}
