import openai
from fastapi import FastAPI, Depends, HTTPException, Request
from fastapi.middleware.cors import CORSMiddleware
from fastapi.responses import HTMLResponse
from pydantic import BaseModel

# define the OpenAI API key in your user environment variables or in the code below

# openai.api_key = '''yourkey'''

app = FastAPI()

app.add_middleware(
    CORSMiddleware,
    allow_origins=["*"],
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)

class ChatInput(BaseModel):
    message: str

@app.post("/chat/")
async def chat(chat_input: ChatInput):
    user_message = chat_input.message

    response = openai.ChatCompletion.create(
        model="gpt-3.5-turbo",
        messages=[
            {"role": "system", "content": "You are a helpful assistant."},
            {"role": "user", "content": user_message},
        ]
    )

    assistant_message = response.choices[0].message.content
    return {"assistant": assistant_message}

@app.get("/", response_class=HTMLResponse)
async def root(request: Request):
    return """
    <!DOCTYPE html>
    <html>
        <head>
    <style>
        body {
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            background-color: #f5f5f5;
            margin: 50px;
        }
        .chat-container {
            display: flex;
            flex-direction: column;
            max-width: 600px;
            margin: 0 auto;
            background-color: #ffffff;
            padding: 20px;
            border-radius: 10px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
        }
        .message-container {
            display: flex;
            flex-direction: column;
            margin-bottom: 20px;
        }
        .user-message,
        .assistant-message {
            padding: 10px;
            border-radius: 5px;
            margin-bottom: 5px;
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            font-size: 16px;
        }
        .user-message {
            background-color: #4caf50;
            color: white;
            align-self: flex-end;
        }
        .assistant-message {
            background-color: #2196f3;
            color: white;
        }
        input[type="text"] {
            flex-grow: 1;
            padding: 10px;
            border: 1px solid #ccc;
            border-radius: 5px;
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            font-size: 16px;
        }
        button {
            padding: 10px 20px;
            background-color: #2196f3;
            color: white;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            font-size: 16px;
            transition: background-color 0.3s;
        }
        button:hover {
            background-color: #42a5f5;
        }
    </style>
</head>
        <body>
            <div class="chat-container">
                <div id="message-display" class="message-display"></div>
                <div>
                    <input id="message-input" type="text" placeholder="Type your message...">
                    <button onclick="sendMessage()">Send</button>
                </div>
            </div>
            <script>
                async function sendMessage() {
                    const messageInput = document.getElementById("message-input");
                    const messageDisplay = document.getElementById("message-display");
                    
                    const userMessage = messageInput.value;
                    messageInput.value = "";

                    const userDiv = document.createElement("div");
                    userDiv.className = "message-container user-message";
                    userDiv.innerText = userMessage;
                    messageDisplay.appendChild(userDiv);

                    const response = await fetch("/chat/", {
                        method: "POST",
                        headers: {
                            "Content-Type": "application/json"
                        },
                        body:                         JSON.stringify({ message: userMessage })
                    });

                    const data = await response.json();
                    const assistantMessage = data.assistant;

                    const assistantDiv = document.createElement("div");
                    assistantDiv.className = "message-container assistant-message";
                    assistantDiv.innerText = assistantMessage;
                    messageDisplay.appendChild(assistantDiv);

                    messageDisplay.scrollTop = messageDisplay.scrollHeight;
                }
            </script>
        </body>
    </html>
    """

